betty.locale.localizable.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.locale.localizable.config module

Provide localizable configuration.

final class betty.locale.localizable.config.OptionalStaticTranslationsLocalizableConfigurationAttr

  Bases: `_StaticTranslationsLocalizableConfigurationAttr`

  An instance attribute that contains `betty.locale.localizable.config.StaticTranslationsLocalizableConfiguration`.

final class betty.locale.localizable.config.RequiredStaticTranslationsLocalizableConfigurationAttr

  Bases: `_StaticTranslationsLocalizableConfigurationAttr`

  An instance attribute that contains `betty.locale.localizable.config.StaticTranslationsLocalizableConfiguration`.

final class betty.locale.localizable.config.StaticTranslationsLocalizableConfiguration

  Bases: `Configuration`, `StaticTranslationsLocalizable`

  Provide configuration for a `betty.locale.localizable.Localizable`.

  Read more at multiple translations.

  dump() → bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]

    Produce a serialized data dump of `self`.

  load(dump: bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]) → None

    Load a serialized data dump into `self`.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump is invalid.